/**
   You can run this program using any one of the three database systems
   that we have used in this class, MySQL, PostgreSQL, and SQLite. This
   file DOES NOT need to be recompiled for each database system. A single
   class file will work with all three database systems. This is part of
   the advantage of using JDBC.

   You switch from one database system to another by using a different
   JDBC interface (which is contained in a jar file) and by changing the
   contents of a properties file that specifies parameters for the
   particular JDBC interface.

   In the zip file there is a JDBC interface for each of the three
   database systems. You specify which database system you want to
   use by specifying which JDBC interface to use in the ClassPath (-cp)
   parameter to the JVM. See the following three commands.
      java -cp .;mysql-connector-java-5.1.6-bin.jar  SuppliersParts
      java -cp .;postgresql-8.3-604.jdbc3.jar  SuppliersParts
      java -cp .;sqlitejdbc-v053-pure.jar  SuppliersParts
  Additionally, this program expects to find a properties file called
  SuppliersParts.properties that contains the proper parameters for
  connecting to each of the database systems. In this zip file there
  is a properties file for each database. Rename the appropriate
  properties file to SuppliersParts.properties before you run this program.

  This program assumes that the database itself has already been created.
  A copy of the SQLite database is included in this zip file. And there
  is an SQL script that can be used to build the database in either MySQL
  or PostgreSQL.
 */
import java.sql.Connection;
import java.sql.DriverManager;
import java.sql.Statement;
import java.sql.ResultSet;
import java.sql.ResultSetMetaData;
import java.sql.SQLException;
import java.io.FileInputStream;
import java.io.IOException;
import java.util.Properties;

class SuppliersParts
{
   public static void main (String args[]) throws Exception
   {
      Connection con;
      Statement stmt;
      try
      {
         con = getDatabaseConnection();

         stmt = con.createStatement();

         String tableName = "S";

         String query = "SELECT * FROM " + tableName;
         ResultSet rs = stmt.executeQuery(query);
         ResultSetMetaData rsmd = rs.getMetaData();
         int columnCount = rsmd.getColumnCount();
         while (rs.next())
         {
            for (int i = 1; i <= columnCount; i++)
            {
               if (i > 1)
                  System.out.print(", ");
               System.out.print(rs.getString(i));
            }
            System.out.println();
         }

         rs.close();
         stmt.close();
         con.close();
      }
      catch (SQLException ex)
      {
         System.out.println ("SQLException:");
         while (ex != null)
         {
            System.out.println ("SQLState: " + ex.getSQLState());
            System.out.println ("Message:  " + ex.getMessage());
            System.out.println ("Vendor:   " + ex.getErrorCode());
            System.out.println ("");
            ex = ex.getNextException();
         }
      }
      catch (IOException ex)
      {
         System.out.println("Exception: " + ex);
         ex.printStackTrace ();
      }
      finally
      {
      }
   }


   public static Connection getDatabaseConnection() throws SQLException, IOException
   {
      Properties props = new Properties();
      String fileName = "SuppliersParts.properties";
      FileInputStream in = new FileInputStream(fileName);
      props.load(in);

      String drivers = props.getProperty("jdbc.drivers");
      if (drivers != null)
         System.setProperty("jdbc.drivers", drivers);
      String url = props.getProperty("jdbc.url");
      String username = props.getProperty("jdbc.username");
      String password = props.getProperty("jdbc.password");

      return DriverManager.getConnection(url, username, password);
   }
}



